==> geopsypack-src-3.3.4.tar.gz: geopsypack-src-3.3.4/HVCore/src/HVTask.h <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-18
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HVTASK_H
#define HVTASK_H

#include <QGpCoreTools.h>

#include "HVCoreDLLExport.h"

namespace HVCore {

  class HVTaskManager;
  class AbstractStation;

  class HVCORE_EXPORT HVTask : public AbstractTask
  {
  public:
    HVTask(HVTaskManager * manager,
           int taskIndex,
           AbstractStation * station);
    ~HVTask();

    void init();
    void polish();
    AbstractStation * station() const {return _station;}
    HVTaskManager * taskManager() const;
  private:
    AbstractStation * _station;
  };

} // namespace HVCore

#endif // HVTASK_H

==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/HVCore/src/HVTask.h <==
/***************************************************************************
**
**  This file is part of HVCore.
**
**  HVCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  HVCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2020-02-18
**  Copyright: 2020
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef HVTASK_H
#define HVTASK_H

#include <QGpCoreTools.h>

#include "HVCoreDLLExport.h"

namespace HVCore {

  class HVTaskManager;
  class AbstractStation;

  class HVCORE_EXPORT HVTask : public ParallelTask
  {
  public:
    HVTask(HVTaskManager * manager,
           int taskIndex,
           AbstractStation * station);
    ~HVTask();

    void init();
    void polish();
    AbstractStation * station() const {return _station;}
  private:
    inline const HVTaskManager * taskManager() const;

    AbstractStation * _station;
  };

} // namespace HVCore

#endif // HVTASK_H
